summaryrefslogtreecommitdiffstats
path: root/lib/compatibility/kmdi/qextmdi/kmdimainfrm.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/compatibility/kmdi/qextmdi/kmdimainfrm.cpp')
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdimainfrm.cpp54
1 files changed, 27 insertions, 27 deletions
diff --git a/lib/compatibility/kmdi/qextmdi/kmdimainfrm.cpp b/lib/compatibility/kmdi/qextmdi/kmdimainfrm.cpp
index 4449cb4f..aaa07ff8 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdimainfrm.cpp
+++ b/lib/compatibility/kmdi/qextmdi/kmdimainfrm.cpp
@@ -38,7 +38,7 @@
#include <assert.h>
#include <tqcursor.h>
-#include <clipboard.h>
+#include <tqclipboard.h>
#include <tqobjectlist.h>
#include <tqpopupmenu.h>
#include <tqmenubar.h>
@@ -56,9 +56,9 @@
#include <tqtoolbutton.h>
#include <tqdockarea.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqtimer.h>
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqstring.h>
#include <tqmap.h>
#include <tqvaluelist.h>
@@ -298,16 +298,16 @@ void KMdiMainFrm::setStandardMDIMenuEnabled( bool showModeMenu )
//============ ~KMdiMainFrm ============//
KMdiMainFrm::~KMdiMainFrm()
{
- //save the children first to a list, as removing invalidates our iterator
- TQValueList<KMdiChildView*> children;
+ //save the tqchildren first to a list, as removing invalidates our iterator
+ TQValueList<KMdiChildView*> tqchildren;
for ( KMdiChildView * w = m_pDocumentViews->first();w;w = m_pDocumentViews->next() )
- children.append( w );
+ tqchildren.append( w );
// safely close the windows so properties are saved...
TQValueListIterator<KMdiChildView*> childIt;
- for ( childIt = children.begin(); childIt != children.end(); ++childIt )
+ for ( childIt = tqchildren.begin(); childIt != tqchildren.end(); ++childIt )
{
- closeWindow( *childIt, false ); // without re-layout taskbar!
+ closeWindow( *childIt, false ); // without re-tqlayout taskbar!
}
emit lastChildViewClosed();
@@ -423,7 +423,7 @@ KMdiChildView* KMdiMainFrm::createWrapper( TQWidget *view, const TQString& name,
KMdiChildView* pMDICover = new KMdiChildView( name /*caption*/, 0L /*parent*/,
name.latin1() );
- TQBoxLayout* pLayout = new TQHBoxLayout( pMDICover, 0, -1, "layout" );
+ TQBoxLayout* pLayout = new TQHBoxLayout( pMDICover, 0, -1, "tqlayout" );
view->reparent( pMDICover, TQPoint( 0, 0 ) );
pLayout->addWidget( view );
// pMDICover->setName(name);
@@ -586,7 +586,7 @@ KMdiToolViewAccessor *KMdiMainFrm::addToolWindow( TQWidget* pWnd, KDockWidget::D
pWnd = pDW;
}
- TQRect r = pWnd->geometry();
+ TQRect r = pWnd->tqgeometry();
KMdiToolViewAccessor *mtva = new KMdiToolViewAccessor( this, pWnd, tabToolTip, ( tabCaption == 0 ) ? pWnd->caption() : tabCaption );
m_pToolViews->insert( tvta, mtva );
@@ -614,7 +614,7 @@ void KMdiMainFrm::attachWindow( KMdiChildView *pWnd, bool bShow, bool bAutomatic
TQRect frameGeo = pWnd->frameGeometry();
TQPoint topLeftScreen = pWnd->mapToGlobal( TQPoint( 0, 0 ) );
TQPoint topLeftMdiChildArea = m_pMdi->mapFromGlobal( topLeftScreen );
- TQRect childAreaGeo = m_pMdi->geometry();
+ TQRect childAreaGeo = m_pMdi->tqgeometry();
if ( topLeftMdiChildArea.x() < 0 || topLeftMdiChildArea.y() < 0 ||
( topLeftMdiChildArea.x() + frameGeo.width() > childAreaGeo.width() ) ||
( topLeftMdiChildArea.y() + frameGeo.height() > childAreaGeo.height() ) )
@@ -643,7 +643,7 @@ void KMdiMainFrm::attachWindow( KMdiChildView *pWnd, bool bShow, bool bAutomatic
m_pMdi->manageChild( lpC, false, bCascade );
if ( m_pMdi->topChild() && m_pMdi->topChild() ->isMaximized() )
{
- TQRect r = lpC->geometry();
+ TQRect r = lpC->tqgeometry();
lpC->setGeometry( -lpC->m_pClient->x(), -lpC->m_pClient->y(),
m_pMdi->width() + KMDI_CHILDFRM_DOUBLE_BORDER,
m_pMdi->height() + lpC->captionHeight() + KMDI_CHILDFRM_SEPARATOR + KMDI_CHILDFRM_DOUBLE_BORDER );
@@ -705,7 +705,7 @@ void KMdiMainFrm::detachWindow( KMdiChildView *pWnd, bool bShow )
#ifdef TQ_WS_X11
if ( mdiMode() == KMdi::ToplevelMode )
{
- XSetTransientForHint( qt_xdisplay(), pWnd->winId(), topLevelWidget() ->winId() );
+ XSetTransientForHint( qt_xdisplay(), pWnd->winId(), tqtopLevelWidget() ->winId() );
}
#endif
@@ -715,7 +715,7 @@ void KMdiMainFrm::detachWindow( KMdiChildView *pWnd, bool bShow )
#ifdef TQ_WS_X11
if ( mdiMode() == KMdi::ToplevelMode )
{
- XSetTransientForHint( qt_xdisplay(), pWnd->winId(), topLevelWidget() ->winId() );
+ XSetTransientForHint( qt_xdisplay(), pWnd->winId(), tqtopLevelWidget() ->winId() );
}
#endif
@@ -1238,14 +1238,14 @@ bool KMdiMainFrm::eventFilter( TQObject * /*obj*/, TQEvent *e )
*/
void KMdiMainFrm::closeAllViews()
{
- //save the children first to a list, as removing invalidates our iterator
- TQValueList<KMdiChildView*> children;
+ //save the tqchildren first to a list, as removing invalidates our iterator
+ TQValueList<KMdiChildView*> tqchildren;
for ( KMdiChildView * w = m_pDocumentViews->first();w;w = m_pDocumentViews->next() )
{
- children.append( w );
+ tqchildren.append( w );
}
TQValueListIterator<KMdiChildView *> childIt;
- for ( childIt = children.begin(); childIt != children.end(); ++childIt )
+ for ( childIt = tqchildren.begin(); childIt != tqchildren.end(); ++childIt )
{
( *childIt )->close();
}
@@ -1273,7 +1273,7 @@ void KMdiMainFrm::closeActiveView()
m_pCurrentWindow->close();
}
/** find the root dockwidgets and store their geometry */
void KMdiMainFrm::findRootDockWidgets( TQPtrList<KDockWidget>* rootDockWidgetList, TQValueList<TQRect>* positionList )
{
//nothing is valid
@@ -1289,7 +1289,7 @@ void KMdiMainFrm::findRootDockWidgets( TQPtrList<KDockWidget>* rootDockWidgetLis
pObjList = queryList( "KDockWidget_Compat::KDockWidget" );
TQObjectListIt it( *pObjList );
// for all dockwidgets (which are children of this mainwindow)
while ( ( *it ) )
{
KDockWidget* dockWindow = 0L; /* pDockW */
@@ -1357,7 +1357,7 @@ void KMdiMainFrm::switchToToplevelMode()
const int frameBorderWidth = 7; // @todo: Can we / do we need to ask the window manager?
setUndockPositioningOffset( TQPoint( 0, ( m_pTaskBar ? m_pTaskBar->height() : 0 ) + frameBorderWidth ) );
// 1.) select the dockwidgets to be undocked and store their geometry
TQPtrList<KDockWidget> rootDockWidgetList;
TQValueList<TQRect> positionList;
@@ -1470,7 +1470,7 @@ void KMdiMainFrm::switchToChildframeMode()
if ( m_mdiMode == KMdi::TabPageMode )
{
kdDebug(760) << k_funcinfo << "finishing tab page mode" << endl;
// select the dockwidgets to be undocked and store their geometry
findRootDockWidgets( &rootDockWidgetList, &positionList );
kdDebug(760) << k_funcinfo << "Found " << rootDockWidgetList.count() << " widgets to undock" << endl;
@@ -1490,7 +1490,7 @@ void KMdiMainFrm::switchToChildframeMode()
kdDebug(760) << k_funcinfo << "finishing ideal mode" << endl;
finishIDEAlMode( false );
// select the dockwidgets to be undocked and store their geometry
findRootDockWidgets( &rootDockWidgetList, &positionList );
kdDebug(760) << k_funcinfo << "Found " << rootDockWidgetList.count() << " widgets to undock" << endl;
@@ -1663,8 +1663,8 @@ void KMdiMainFrm::finishTabPageMode()
if ( pView->isToolView() )
continue;
kdDebug(760) << "KMdiMainFrm::finishTabPageMode: in loop" << endl;
- TQSize mins = pView->minimumSize();
- TQSize maxs = pView->maximumSize();
+ TQSize mins = pView->tqminimumSize();
+ TQSize maxs = pView->tqmaximumSize();
TQSize sz = pView->size();
TQWidget* pParent = pView->parentWidget();
TQPoint p( pParent->mapToGlobal( pParent->pos() ) - pParent->pos() + m_undockPositioningOffset );
@@ -2079,8 +2079,8 @@ void KMdiMainFrm::finishIDEAlMode( bool full )
KMdiChildView* pView = it.current();
if ( pView->isToolView() )
continue;
- TQSize mins = pView->minimumSize();
- TQSize maxs = pView->maximumSize();
+ TQSize mins = pView->tqminimumSize();
+ TQSize maxs = pView->tqmaximumSize();
TQSize sz = pView->size();
TQWidget* pParent = pView->parentWidget();
TQPoint p( pParent->mapToGlobal( pParent->pos() ) - pParent->pos() + m_undockPositioningOffset );
@@ -1273,7 +1273,7 @@ void KMdiMainFrm::closeActiveView()
m_pCurrentWindow->close();
}
-/** find the root dockwidgets and store their geometry */
+/** find the root dockwidgets and store their tqgeometry */
void KMdiMainFrm::findRootDockWidgets( TQPtrList<KDockWidget>* rootDockWidgetList, TQValueList<TQRect>* positionList )
{
@@ -1289,7 +1289,7 @@ void KMdiMainFrm::findRootDockWidgets( TQPtrList<KDockWidget>* rootDockWidgetLis
pObjList = queryList( "KDockWidget_Compat::KDockWidget" );
TQObjectListIt it( *pObjList );
- // for all dockwidgets (which are children of this mainwindow)
+ // for all dockwidgets (which are tqchildren of this mainwindow)
while ( ( *it ) )
{
@@ -1357,7 +1357,7 @@ void KMdiMainFrm::switchToToplevelMode()
const int frameBorderWidth = 7; // @todo: Can we / do we need to ask the window manager?
setUndockPositioningOffset( TQPoint( 0, ( m_pTaskBar ? m_pTaskBar->height() : 0 ) + frameBorderWidth ) );
- // 1.) select the dockwidgets to be undocked and store their geometry
+ // 1.) select the dockwidgets to be undocked and store their tqgeometry
TQPtrList<KDockWidget> rootDockWidgetList;
TQValueList<TQRect> positionList;
@@ -1470,7 +1470,7 @@ void KMdiMainFrm::switchToChildframeMode()
{
kdDebug(760) << k_funcinfo << "finishing tab page mode" << endl;
- // select the dockwidgets to be undocked and store their geometry
+ // select the dockwidgets to be undocked and store their tqgeometry
findRootDockWidgets( &rootDockWidgetList, &positionList );
kdDebug(760) << k_funcinfo << "Found " << rootDockWidgetList.count() << " widgets to undock" << endl;
@@ -1490,7 +1490,7 @@ void KMdiMainFrm::switchToChildframeMode()
kdDebug(760) << k_funcinfo << "finishing ideal mode" << endl;
finishIDEAlMode( false );
- // select the dockwidgets to be undocked and store their geometry
+ // select the dockwidgets to be undocked and store their tqgeometry
findRootDockWidgets( &rootDockWidgetList, &positionList );
kdDebug(760) << k_funcinfo << "Found " << rootDockWidgetList.count() << " widgets to undock" << endl;